@@ -12,38 +12,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Protocols are what allow :py:class:`mrjob.job.MRJob` to input and
-output arbitrary values, rather than just strings.
-
-We use JSON as our default protocol rather than something more
-powerful because we want to encourage interoperability with other
-languages. If you need more power, you can represent values as reprs
-or pickles.
-
-Also, if know that your input will always be in JSON format, consider
-:py:class:`JSONValueProtocol` as an alternative to
-:py:class:`RawValueProtocol`.
-
-Custom Protocols
-^^^^^^^^^^^^^^^^
-
-A protocol is an object with methods ``read(self, line)`` and
-``write(self, key, value)``. The ``read(line)`` method takes a string and
-returns a 2-tuple of decoded objects, and ``write(cls, key, value)`` takes
-the key and value and returns the line to be passed back to Hadoop Streaming
-or as output.
-
-For a simpler interface, inherit from :py:class:`KeyCachingProtocol` and
-override :py:meth:`KeyCachingProtocol.load_from_string` and
-:py:meth:`KeyCachingProtocol.load_from_string`. Protocols that follow this
-pattern only decode keys when they differ from the last key seen. This
-optimization can speed up jobs significantly.
-
-The built-in protocols use class methods instead of instance methods for
-legacy reasons, but you should use instance methods.
-
-For more information on using alternate protocols in your job, see
-:ref:`job-protocols`.
+"""Protocols deserialize and serialize the input and output of tasks to raw
+bytes for Hadoop to distribute to the next task or to write as output. For more
+information, see :ref:`job-protocols` and :ref:`writing-protocols`.
 """
 # don't add imports here that aren't part of the standard Python library,
 # since MRJobs need to run in Amazon's generic EMR environment
@@ -53,6 +24,7 @@ from mrjob.util import safeeval
 
 try:
     import simplejson as json  # preferred because of C speedups
+    json  # quiet "redefinition of unused ..." warning from pyflakes
 except ImportError:
     import json  # built in to Python 2.6 and later
 
@@ -168,6 +140,30 @@ class PickleValueProtocol(object):
         return cPickle.dumps(value).encode('string_escape')
 
 
+# This was added in 0.3, so no @classmethod for backwards compatibility
+class RawProtocol(object):
+    """Encode ``(key, value)`` as ``key`` and ``value`` separated by
+    a tab (``key`` and ``value`` should be bytestrings).
+
+    If ``key`` or ``value`` is ``None``, don't include a tab. When decoding a
+    line with no tab in it, ``value`` will be ``None``.
+
+    When reading from a line with multiple tabs, we break on the first one.
+
+    Your key should probably not be ``None`` or have tab characters in it, but
+    we don't check.
+    """
+    def read(cls, line):
+        key_value = line.split('\t', 1)
+        if len(key_value) == 1:
+            key_value.append(None)
+
+        return tuple(key_value)
+
+    def write(cls, key, value):
+        return '\t'.join(x for x in (key, value) if x is not None)
+
+
 class RawValueProtocol(object):
     """Read in a line as ``(None, line)``. Write out ``(key, value)``
     as ``value``. ``value`` must be a ``str``.
@@ -211,33 +207,3 @@ class ReprValueProtocol(object):
     @classmethod
     def write(cls, key, value):
         return repr(value)
-
-#: DEPRECATED
-#:
-#: Formerly the default protocol for all encoded input and output: ``'json'``
-DEFAULT_PROTOCOL = 'json'
-
-#: DEPRECATED
-#:
-#: Default mapping from protocol name to class:
-#:
-#: ============ ===============================
-#: name         class
-#: ============ ===============================
-#: json         :py:class:`JSONProtocol`
-#: json_value   :py:class:`JSONValueProtocol`
-#: pickle       :py:class:`PickleProtocol`
-#: pickle_value :py:class:`PickleValueProtocol`
-#: raw_value    :py:class:`RawValueProtocol`
-#: repr         :py:class:`ReprProtocol`
-#: repr_value   :py:class:`ReprValueProtocol`
-#: ============ ===============================
-PROTOCOL_DICT = {
-    'json': JSONProtocol,
-    'json_value': JSONValueProtocol,
-    'pickle': PickleProtocol,
-    'pickle_value': PickleValueProtocol,
-    'raw_value': RawValueProtocol,
-    'repr': ReprProtocol,
-    'repr_value': ReprValueProtocol,
-}
