@@ -29,6 +29,7 @@ import itertools
 import logging
 import os
 import pipes
+import shlex
 import sys
 import tarfile
 import zipfile
@@ -39,13 +40,26 @@ try:
 except ImportError:
     bz2 = None
 
+#: .. deprecated:: 0.4
 is_ironpython = "IronPython" in sys.version
 
+
 class NullHandler(logging.Handler):
     def emit(self, record):
         pass
 
 
+def bash_wrap(cmd_str):
+    """Escape single quotes in a shell command string and wrap it with ``bash
+    -c '<string>'``.
+
+    This low-tech replacement works because we control the surrounding string
+    and single quotes are the only character in a single-quote string that
+    needs escaping.
+    """
+    return "bash -c '%s'" % cmd_str.replace("'", "'\\''")
+
+
 def buffer_iterator_to_line_iterator(iterator):
     """boto's file iterator splits by buffer size instead of by newline. This
     wrapper puts them back into lines.
@@ -378,12 +392,17 @@ def read_file(path, fileobj=None):
     - Decompress ``.gz`` and ``.bz2`` files.
     - If *fileobj* is not ``None``, stream lines from the *fileobj*
     """
+    # sometimes values declared in the ``try`` block aren't accessible from the
+    # ``finally`` block. not sure why.
+    f = None
     try:
         if path.endswith('.gz'):
             f = gzip.GzipFile(path, fileobj=fileobj)
         elif path.endswith('.bz2'):
             if bz2 is None:
-                raise Exception('bz2 module was not successfully imported (likely not installed).')
+                f = None
+                raise Exception('bz2 module was not successfully imported'
+                                ' (likely not installed).')
             elif fileobj is None:
                 f = bz2.BZ2File(path)
             else:
@@ -396,7 +415,7 @@ def read_file(path, fileobj=None):
         for line in f:
             yield line
     finally:
-        if fileobj is None and not f is None: 
+        if fileobj is None and not f is None:
             f.close()
 
 
@@ -491,6 +510,16 @@ def safeeval(expr, globals=None, locals=None):
     return eval(expr, safe_globals, locals)
 
 
+def shlex_split(s):
+    """Wrapper around shlex.split(), but convert to str if Python version <
+    2.7.3 when unicode support was added.
+    """
+    if sys.version_info < (2, 7, 3):
+        return shlex.split(str(s))
+    else:
+        return shlex.split(s)
+
+
 def strip_microseconds(delta):
     """Return the given :py:class:`datetime.timedelta`, without microseconds.
 
